# kudosdeluxe/migrations/0003_add_oauth_state.py

import uuid

from django.db import migrations, models


def generate_oauth_state(apps, schema_editor):
    StravaToken = apps.get_model('kudosdeluxe', 'StravaToken')
    for token in StravaToken.objects.all():
        token.oauth_state = uuid.uuid4()
        token.save()

class Migration(migrations.Migration):

    dependencies = [
        ('kudosdeluxe', '0002_remove_stravatoken_access_token_and_more'),
    ]

    operations = [
        # Step 1: Add the field as nullable without unique constraint
        migrations.AddField(
            model_name='stravatoken',
            name='oauth_state',
            field=models.UUIDField(null=True, editable=False),
        ),
        
        # Step 2: Populate existing records with unique UUIDs
        migrations.RunPython(generate_oauth_state),
        
        # Step 3: Alter the field to be non-nullable and unique
        migrations.AlterField(
            model_name='stravatoken',
            name='oauth_state',
            field=models.UUIDField(editable=False, unique=True),
        ),
    ]